@@ -1,7 +1,6 @@
 # ------------------------------------------------------------------------------
-# Name: rindcalc.indices.py
+# Name: rindcalc.ls.indices.py
 # Author: Owen Smith, University of North Georgia IESA
-# Purpose: Create a functioning python module for Landsat 8 index calculations
 # ------------------------------------------------------------------------------
 
 import os
@@ -64,10 +63,10 @@ def AWEIsh(landsat_dir, aweish_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, aweish_out, snap)
-        return masked, print('Finished')
+        return masked, print(aweish_out)
     if not mask_clouds:
         save_raster(equation, aweish_out, snap)
-        return equation, print('Finished')
+        return equation, print(aweish_out)
 
 
 def AWEInsh(landsat_dir, aweinsh_out, mask_clouds=False):
@@ -118,10 +117,10 @@ def AWEInsh(landsat_dir, aweinsh_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, aweinsh_out, snap)
-        return masked, print('Finished')
+        return masked, print(aweinsh_out)
     if not mask_clouds:
         save_raster(equation, aweinsh_out, snap)
-        return equation, print('Finished')
+        return equation, print(aweinsh_out)
 
 
 def NDMI(landsat_dir, ndmi_out, mask_clouds=False):
@@ -144,7 +143,7 @@ def NDMI(landsat_dir, ndmi_out, mask_clouds=False):
     """
     # Create list with file names
     nir = glob(os.path.join(landsat_dir, '*B5*'))
-    swir1 = glob(os.path.join(landsat_dir, '/*B6*'))
+    swir1 = glob(os.path.join(landsat_dir, '*B6*'))
 
     # Open with gdal & create numpy arrays
     gdal.UseExceptions()
@@ -162,10 +161,10 @@ def NDMI(landsat_dir, ndmi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, ndmi_out, snap)
-        return masked, print('Finished')
+        return masked, print(ndmi_out)
     if not mask_clouds:
         save_raster(equation, ndmi_out, snap)
-        return equation, print('Finished')
+        return equation, print(ndmi_out)
 
 
 def MNDWI(landsat_dir, mndwi_out, mask_clouds=False):
@@ -206,10 +205,10 @@ def MNDWI(landsat_dir, mndwi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, mndwi_out, snap)
-        return masked, print('Finished')
+        return masked, print(mndwi_out)
     if not mask_clouds:
         save_raster(equation, mndwi_out, snap)
-        return equation, print('Finished')
+        return equation, print(mndwi_out)
 
 
 def NDVI(landsat_dir, ndvi_out, mask_clouds=False):
@@ -252,10 +251,10 @@ def NDVI(landsat_dir, ndvi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, ndvi_out, snap)
-        return masked, print('Finished')
+        return masked, print(ndvi_out)
     if not mask_clouds:
         save_raster(equation, ndvi_out, snap)
-        return equation, print('Finished')
+        return equation, print(ndvi_out)
 
 
 def GNDVI(landsat_dir, gndvi_out, mask_clouds=False):
@@ -297,10 +296,10 @@ def GNDVI(landsat_dir, gndvi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, gndvi_out, snap)
-        return masked, print('Finished')
+        return masked, print(gndvi_out)
     if not mask_clouds:
         save_raster(equation, gndvi_out, snap)
-        return equation, print('Finished')
+        return equation, print(gndvi_out)
 
 
 def SAVI(landsat_dir, savi_out, soil_brightness=0.5, mask_clouds=False):
@@ -345,10 +344,10 @@ def SAVI(landsat_dir, savi_out, soil_brightness=0.5, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, savi_out, snap)
-        return masked, print('Finished')
+        return masked, print(savi_out)
     if not mask_clouds:
         save_raster(equation, savi_out, snap)
-        return equation, print('Finished')
+        return equation, print(savi_out)
 
 
 def ARVI(landsat_dir, arvi_out, mask_clouds=False):
@@ -393,10 +392,10 @@ def ARVI(landsat_dir, arvi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, arvi_out, snap)
-        return masked, print('Finished')
+        return masked, print(arvi_out)
     if not mask_clouds:
         save_raster(equation, arvi_out, snap)
-        return equation, print('Finished')
+        return equation, print(arvi_out)
 
 
 def VARI(landsat_dir, vari_out, mask_clouds=False):
@@ -438,10 +437,10 @@ def VARI(landsat_dir, vari_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, vari_out, snap)
-        return masked, print('Finished')
+        return masked, print(vari_out)
     if not mask_clouds:
         save_raster(equation, vari_out, snap)
-        return equation, print('Finished')
+        return equation, print(vari_out)
 
 
 def NDBI(landsat_dir, ndbi_out, mask_clouds=False):
@@ -483,10 +482,10 @@ def NDBI(landsat_dir, ndbi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, ndbi_out, snap)
-        return masked, print('Finished')
+        return masked, print(ndbi_out)
     if not mask_clouds:
         save_raster(equation, ndbi_out, snap)
-        return equation, print('Finished')
+        return equation, print(ndbi_out)
 
 
 def NDBaI(landsat_dir, ndbai_out, mask_clouds=False):
@@ -528,10 +527,10 @@ def NDBaI(landsat_dir, ndbai_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, ndbai_out, snap)
-        return masked, print('Finished')
+        return masked, print(ndbai_out)
     if not mask_clouds:
         save_raster(equation, ndbai_out, snap)
-        return equation, print('Finished')
+        return equation, print(ndbai_out)
 
 
 def NBLI(landsat_dir, nbli_out, mask_clouds=False):
@@ -573,10 +572,10 @@ def NBLI(landsat_dir, nbli_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, nbli_out, snap)
-        return masked, print('Finished')
+        return masked, print(nbli_out)
     if not mask_clouds:
         save_raster(equation, nbli_out, snap)
-        return equation, print('Finished')
+        return equation, print(nbli_out)
 
 
 def EBBI(landsat_dir, ebbi_out, mask_clouds=False):
@@ -623,10 +622,10 @@ def EBBI(landsat_dir, ebbi_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, ebbi_mask)
         save_raster(masked, ebbi_mask, snap)
-        return masked, print('Finished')
+        return masked, print(ebbi_out)
     if not mask_clouds:
         save_raster(ebbi_mask, ebbi_out, snap)
-        return ebbi_mask, print('Finished')
+        return ebbi_mask, print(ebbi_out)
 
 
 def UI(landsat_dir, ui_out, mask_clouds=False):
@@ -666,10 +665,10 @@ def UI(landsat_dir, ui_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, ui_out, snap)
-        return masked, print('Finished')
+        return masked, print(ui_out)
     if not mask_clouds:
         save_raster(equation, ui_out, snap)
-        return equation, print('Finished')
+        return equation, print(ui_out)
 
 
 def NBRI(landsat_dir, nbri_out, mask_clouds=False):
@@ -711,7 +710,46 @@ def NBRI(landsat_dir, nbri_out, mask_clouds=False):
     if mask_clouds:
         masked = cloud_mask_array(landsat_dir, equation)
         save_raster(masked, nbri_out, snap)
-        return masked, print('Finished')
+        return masked, print(nbri_out)
     if not mask_clouds:
         save_raster(equation, nbri_out, snap)
-        return equation, print('Finished')
+        return equation, print(nbri_out)
+
+
+def calculate_all(landsat_dir, out_dir, mask_clouds=False):
+    """
+    calculate_all(landsat_dir, our_dir, mask_clouds=False):
+
+    Calculates all indices in rindcalc.naip.indices for NAIP image and outputs
+    into a specified output folder with the output file names being the name of
+    the function. i.e: NDVI.tif
+
+    Parameters:
+
+            landsat_dir :: str, required
+                * Folder path where all landsat bands for the scene are
+                  contained.
+
+             out_dir :: str, required
+                * File path of output directory.
+
+            mask_clouds :: boolean, optional (default=False)
+                * Whether or not to apply cloud mask to scene based of QA band.
+    """
+    if not os.path.exists(out_dir):
+        os.mkdir(out_dir)
+    AWEIsh(landsat_dir, os.path.join(out_dir, 'AWEIsh.tif'), mask_clouds)
+    AWEInsh(landsat_dir, os.path.join(out_dir, 'AWEInsh.tif'), mask_clouds)
+    NDMI(landsat_dir, os.path.join(out_dir, 'NDMI.tif'), mask_clouds)
+    MNDWI(landsat_dir, os.path.join(out_dir, 'MNDWI.tif'), mask_clouds)
+    NDVI(landsat_dir, os.path.join(out_dir, 'NDVI.tif'), mask_clouds)
+    GNDVI(landsat_dir, os.path.join(out_dir, 'GNDVI.tif'), mask_clouds)
+    SAVI(landsat_dir, os.path.join(out_dir, 'SAVI.tif'),
+         mask_clouds=mask_clouds)
+    ARVI(landsat_dir, os.path.join(out_dir, 'ARVI.tif'), mask_clouds)
+    NDBI(landsat_dir, os.path.join(out_dir, 'NDBI.tif'), mask_clouds)
+    NDBaI(landsat_dir, os.path.join(out_dir, 'NDBaI.tif'), mask_clouds)
+    NBLI(landsat_dir, os.path.join(out_dir, 'NBLI.tif'), mask_clouds)
+    EBBI(landsat_dir, os.path.join(out_dir, 'EBBI.tif'), mask_clouds)
+    UI(landsat_dir, os.path.join(out_dir, 'UI.tif'), mask_clouds)
+    NBRI(landsat_dir, os.path.join(out_dir, 'NBRI.tif'), mask_clouds)
